@@ -23,7 +23,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 """
 
-from subprocess import Popen, PIPE
+import subprocess
 import os
 import sys
 import shlex
@@ -31,8 +31,7 @@ import shlex
 
 class Git(object):
 
-    stdout = ""
-    stderr = ""
+    output = ""
     gitbin = "git"
 
     def __init__(self, path=None, direct_output=True):
@@ -48,28 +47,28 @@ class Git(object):
     def _evaluate(self, command):
         command = shlex.split(command)
         if self.direct_output:
-            p = Popen(command, cwd=self.path)
+            p = subprocess.Popen(command, cwd=self.path)
             p.communicate()
             if p.poll() != 0:
                 raise RuntimeError("exit code: {}".format(p.poll()))
         else:
-            p = Popen(command, cwd=self.path, stdout=PIPE,
-                      stderr=PIPE, universal_newlines=True)
-            self.stdout, self.stderr = p.communicate()
+            p = subprocess.Popen(command, cwd=self.path, stdout=subprocess.PIPE,
+                                 stderr=subprocess.STDOUT, universal_newlines=True)
+            self.output, stderr = p.communicate()
             if p.poll() != 0:
-                raise RuntimeError("{}".format(self.stderr))
+                raise RuntimeError("{}".format(self.output))
 
     def _update_path(self, args):
         if len(args) >= 2:
             p = str(args[1])
-            self.path = p.strip()
+            self.path = self.path+"/"+p.strip()
         else:
             p = str(args[0])
             p = p.split("/")
             p = p[-1]
             if p.endswith(".git"):
                 p = p[:-3]
-                self.path = p.strip()
+            self.path = self.path+"/"+p.strip()
 
     def __getattr__(self,
                     name):
@@ -77,7 +76,8 @@ class Git(object):
         def call_git(*args):
 
             arg = " ".join([str(i) for i in args])
-            command = "{0} {1} {2}".format(self.gitbin, name, arg)
+            command = "{0} {1} {2}".format(
+                self.gitbin, name.replace("_", "-"), arg)
             self._evaluate(command)
             if name == "clone":
                 self._update_path(args)
